@@ -424,8 +424,8 @@ class MainWindow(QMainWindow):
             raise ValueError('Dont run inference without using a proper feature extractor weights! {}'.format(weights))
 
         args = [
-            'python', '-m', 'deepethogram.feature_extractor.inference', 'project.path={}'.format(self.cfg.project.path),
-            'inference.overwrite=True', weight_arg
+            'python', '-m', 'deepethogram.feature_extractor.inference',
+            'project.path={}'.format(self.cfg.project.path), 'inference.overwrite=True', weight_arg
         ]
         flow_weights = self.get_selected_models()['flow_generator']
         assert flow_weights is not None
@@ -800,10 +800,10 @@ class MainWindow(QMainWindow):
         self.initialize_label(label_array=array)
 
     def import_external_labels(self):
-        if hasattr(self, 'project_config'):
+        if self.data_path is not None:
             data_dir = self.data_path
         else:
-            raise ValueError('create or load a DEG project before loading video')
+            raise ValueError('create or load a DEG project before importing video')
 
         options = QFileDialog.Options()
         filestring = 'Label file (*.csv)'
@@ -845,7 +845,7 @@ class MainWindow(QMainWindow):
 
         self.postprocessor = get_postprocessor_from_cfg(self.cfg, thresholds)
         estimated_labels = self.postprocessor(probabilities)
-
+        # this is for visualization purposes only
         probabilities[estimated_labels == 1] = 1
 
         self.probabilities = probabilities
@@ -952,7 +952,7 @@ class MainWindow(QMainWindow):
         self.user_did_something()
 
     def add_multiple_videos(self):
-        if hasattr(self, 'project_config'):
+        if self.data_path is not None:
             data_dir = self.data_path
         else:
             raise ValueError('create or load a DEG project before loading video')
